Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/progressbar_simpletest.py
    :caption: examples/progressbar_simpletest.py
    :linenos:


Color Scale
------------

Example showing how to change the progressbar color while updating the values

.. literalinclude:: ../examples/progressbar_displayio_blinka_color_scale.py
    :caption: examples/progressbar_displayio_blinka_color_scale.py
    :linenos:
